bayespy.nodes.Function
======================

.. currentmodule:: bayespy.nodes

.. autoclass:: Function

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Function.__init__
      ~Function.add_plate_axis
      ~Function.broadcasting_multiplier
      ~Function.delete
      ~Function.get_mask
      ~Function.get_moments
      ~Function.get_shape
      ~Function.has_plotter
      ~Function.lower_bound_contribution
      ~Function.move_plates
      ~Function.plot
      ~Function.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Function.plates
      ~Function.plates_multiplier
   
   